@@ -6,6 +6,7 @@ import (
 	"context"
 	"fmt"
 	"log"
+	"time"
 
 	"github.com/zclconf/go-cty/cty"
 
@@ -126,6 +127,14 @@ func (d *Datasource) Execute() (cty.Value, error) {
 			"image iteration from HCP Packer registry: %s", err.Error())
 	}
 
+	revokeAt := time.Time(iteration.RevokeAt)
+	if !revokeAt.IsZero() && revokeAt.Before(time.Now().UTC()) {
+		// If RevokeAt is not a zero date and is before NOW, it means this iteration is revoked and should not be used
+		// to build new images.
+		return cty.NullVal(cty.EmptyObject), fmt.Errorf("the iteration %s is revoked and can not be used on Packer builds",
+			iteration.ID)
+	}
+
 	output := DatasourceOutput{}
 
 	cloudAndRegions := map[string][]string{}
