@@ -1,6 +1,7 @@
 package hcl2template
 
 import (
+	"os"
 	"path/filepath"
 	"testing"
 
@@ -11,6 +12,9 @@ import (
 )
 
 func Test_ParseHCPPackerRegistryBlock(t *testing.T) {
+	os.Setenv("HCP_PACKER_BUILD_FINGERPRINT", "hcp-par-test")
+	defer os.Unsetenv("HCP_PACKER_BUILD_FINGERPRINT")
+
 	defaultParser := getBasicParser()
 
 	tests := []parseTest{
